function M = randPageRank(n, density)
% Function to create a random sparse PageRank matrix

% INPUTS: - n: the matrix size
%         - density: value between 0 and 1, representing the probability
%           that a page links to some other page (i.e., the number of links
%           will be roughly density*n^2)

if ~(round(n) == n && n > 0)
   error('n must be a positive integer') 
end
if density < 0 || density > 1
    error('density parameter must be in [0, 1]')
end
% Get random sparse binary matrix, with zeros on the diagonal
M = logical(speye(n)+sprand(n, n, density));
M = M - speye(n);
% Deal with any all-zero columns j by adding 1-6 random links
colSums = full(sum(M));
zeroCols = 1:n; zeroCols = zeroCols(colSums == 0);
for col = zeroCols
    nNewLinks = randi(6, 1, 1);
    newLinks = datasample([1:col-1, col+1:n], nNewLinks, 'Replace',...
        false);
    M(newLinks, col) = 1;
    colSums(col) = colSums(col) + nNewLinks;
end
% Divide entries by column sums
for i=1:n
   M(:,i) = M(:,i)/colSums(i);
end

end