function randomWalkDemo(nSteps)
% function to simulate the random walk for the specified number of steps
% through the graph in the CS320 PageRank notes

% Set up adjacency lists as a cell array -- M{i} includes the outgoing
% edges from node i
M = cell(11,1);
M{1} = []; %A (points to nobody)
M{2} = 3; %B (points to C)
M{3} = 2; %C
M{4} = [1,2]; %D
M{5} = [2,4,6]; %E
M{6} = [2,5]; %F
M{7} = [2,5]; %G
M{8} = [2,5]; %H
M{9} = [2,5]; %I
M{10} = 5; %J
M{11} = 5; %K

fprintf('Random walk with %d steps...\n\n',nSteps)

nVisits = zeros(11,1); %number of times each node is visited
currentNode = randi(11,1); %Random starting node
nVisits(currentNode) = 1;
for step=2:nSteps
    damping_c = randi(6,1);
    newRandStart = (damping_c == 6);
    if newRandStart || isempty(M{currentNode})
        % need to start at a new node
        currentNode = randi(11,1);
    else
        % choose at random from currentNode's outgoing links
        if length(M{currentNode}) > 1
            currentNode = randsample(M{currentNode},1);
        else %only one outgoing node -- just pick that one
           currentNode = M{currentNode}; 
        end
    end
    nVisits(currentNode) = nVisits(currentNode) + 1;
end

%Print out information
nodeNames = {'A','B','C','D','E','F','G','H','I','J','K'};
for i=1:11
   fprintf('Node %s: %d visits (%.2f%%)\n',nodeNames{i},nVisits(i),...
       nVisits(i)/nSteps*100);
end
fprintf('\n')

end